@@ -1,8 +1,13 @@
 from quickbuild.adapters.aio import AsyncQBClient
 from quickbuild.adapters.sync import QBClient
-from quickbuild.exceptions import QBError, QBNotFoundError, QBProcessingError
+from quickbuild.exceptions import (
+    QBError,
+    QBForbidden,
+    QBNotFoundError,
+    QBProcessingError,
+)
 
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 
 __all__ = (
     # adapters
@@ -10,6 +15,7 @@ __all__ = (
     'QBClient',
     # exceptions
     'QBError',
+    'QBForbidden',
     'QBNotFoundError',
     'QBProcessingError',
 )
