@@ -4,7 +4,13 @@ from http import HTTPStatus
 from typing import Any, Callable, NamedTuple, Optional
 
 from quickbuild.endpoints.builds import Builds
-from quickbuild.exceptions import QBError, QBNotFoundError, QBProcessingError
+from quickbuild.endpoints.users import Users
+from quickbuild.exceptions import (
+    QBError,
+    QBForbidden,
+    QBNotFoundError,
+    QBProcessingError,
+)
 
 Response = namedtuple('Response', ['status', 'body'])
 
@@ -17,6 +23,7 @@ class QuickBuild(ABC):
 
     def __init__(self):
         self.builds = Builds(self)
+        self.users = Users(self)
 
     @staticmethod
     def _callback(response: Response, fcb: Optional[Callable] = None) -> str:
@@ -26,6 +33,9 @@ class QuickBuild(ABC):
         if response.status == HTTPStatus.NOT_FOUND:
             raise QBNotFoundError(response.body)
 
+        if response.status == HTTPStatus.FORBIDDEN:
+            raise QBForbidden(response.body)
+
         if response.status != HTTPStatus.OK:
             raise QBError(response.body)
 
