@@ -12,6 +12,13 @@ class QBProcessingError(QBError):
     ...
 
 
+class QBForbidden(QBError):
+    """
+    Raises when request return HTTP code 403 (forbidden)
+    """
+    ...
+
+
 class QBNotFoundError(QBError):
     """
     Raises when request return HTTP code 404 (not found)
